from qcanvas.icons import rc_icons

main_icon = ":/main_icon.svg"
file_downloaded = ":/file-downloaded.svg"
file_not_downloaded = ":/file-not-downloaded.svg"
file_download_failed = ":/file-download-failed.svg"
file_unknown = ":/file-unknown.svg"
